From 285c679e1bff0a35cd400828182aca53c93083b1 Mon Sep 17 00:00:00 2001
From: Matthijs van der Vleuten <matthijs@zr40.nl>
Date: Sun, 21 Mar 2021 20:24:37 +0100
Subject: [PATCH] In psql \?, add [+] annotation.

User inoas on IRC channel #postgresql noted that according to \?, \do is not described as supporting the + option while it does in fact recognize the option. Additionally, \dAp and \dy also support +. This patch adds the annotation to \?.

Also fix some obvious errors in translations of the \? text:

* correct inconsistent alignment. This was especially egregious in fr.po. Differing alignment across sections in es.po is preserved as this may have been a deliberate choice by the translator.
* cs.po: remove extraneous newline
* es.po: replace incorrect mention of \do with the correct \dAc, \dAf and \dAo
* fr.po: merge some small lines that still fit within 78 chars
* fr.po: remove [brackets] denoting optional parameters, when these aren't present in the English text
* fr.po: \sv was shown as accepting "FONCTION". This is replaced with "VUE".
* fr.po: \t was missing its optional [on|off] parameter.
* tr.po: fix typo at \d
* uk.po: add missing newline at \c
---
 src/bin/psql/help.c      |   6 +-
 src/bin/psql/po/cs.po    |  34 +++---
 src/bin/psql/po/de.po    |  12 +--
 src/bin/psql/po/es.po    |  22 ++--
 src/bin/psql/po/fr.po    | 227 +++++++++++++++++++--------------------
 src/bin/psql/po/it.po    |   8 +-
 src/bin/psql/po/ja.po    |  10 +-
 src/bin/psql/po/ko.po    |  10 +-
 src/bin/psql/po/ru.po    |   8 +-
 src/bin/psql/po/sv.po    |  14 +--
 src/bin/psql/po/tr.po    |  58 +++++-----
 src/bin/psql/po/uk.po    |  44 ++++----
 src/bin/psql/po/zh_CN.po |   8 +-
 13 files changed, 227 insertions(+), 234 deletions(-)

diff --git a/src/bin/psql/help.c b/src/bin/psql/help.c
index d027a4e3f0..640035f588 100644
--- a/src/bin/psql/help.c
+++ b/src/bin/psql/help.c
@@ -231,7 +231,7 @@ slashUsage(unsigned short int pager)
 	fprintf(output, _("  \\dAc[+] [AMPTRN [TYPEPTRN]]  list operator classes\n"));
 	fprintf(output, _("  \\dAf[+] [AMPTRN [TYPEPTRN]]  list operator families\n"));
 	fprintf(output, _("  \\dAo[+] [AMPTRN [OPFPTRN]]   list operators of operator families\n"));
-	fprintf(output, _("  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"));
+	fprintf(output, _("  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"));
 	fprintf(output, _("  \\db[+]  [PATTERN]      list tablespaces\n"));
 	fprintf(output, _("  \\dc[S+] [PATTERN]      list conversions\n"));
 	fprintf(output, _("  \\dC[+]  [PATTERN]      list casts\n"));
@@ -254,7 +254,7 @@ slashUsage(unsigned short int pager)
 	fprintf(output, _("  \\dL[S+] [PATTERN]      list procedural languages\n"));
 	fprintf(output, _("  \\dm[S+] [PATTERN]      list materialized views\n"));
 	fprintf(output, _("  \\dn[S+] [PATTERN]      list schemas\n"));
-	fprintf(output, _("  \\do[S]  [PATTERN]      list operators\n"));
+	fprintf(output, _("  \\do[S+] [PATTERN]      list operators\n"));
 	fprintf(output, _("  \\dO[S+] [PATTERN]      list collations\n"));
 	fprintf(output, _("  \\dp     [PATTERN]      list table, view, and sequence access privileges\n"));
 	fprintf(output, _("  \\dP[itn+] [PATTERN]    list [only index/table] partitioned relations [n=nested]\n"));
@@ -267,7 +267,7 @@ slashUsage(unsigned short int pager)
 	fprintf(output, _("  \\du[S+] [PATTERN]      list roles\n"));
 	fprintf(output, _("  \\dv[S+] [PATTERN]      list views\n"));
 	fprintf(output, _("  \\dx[+]  [PATTERN]      list extensions\n"));
-	fprintf(output, _("  \\dy     [PATTERN]      list event triggers\n"));
+	fprintf(output, _("  \\dy[+]  [PATTERN]      list event triggers\n"));
 	fprintf(output, _("  \\l[+]   [PATTERN]      list databases\n"));
 	fprintf(output, _("  \\sf[+]  FUNCNAME       show a function's definition\n"));
 	fprintf(output, _("  \\sv[+]  VIEWNAME       show a view's definition\n"));
diff --git a/src/bin/psql/po/cs.po b/src/bin/psql/po/cs.po
index 45771e129d..bf6cc30e96 100644
--- a/src/bin/psql/po/cs.po
+++ b/src/bin/psql/po/cs.po
@@ -2751,19 +2751,17 @@ msgstr "Paměť dotazu\n"
 #: help.c:197
 #, c-format
 msgid "  \\e [FILE] [LINE]       edit the query buffer (or file) with external editor\n"
-msgstr "  \\e [SOUBOR] [ŘÁDEK]           editace aktuálního dotazu (nebo souboru) v externím editoru\n"
+msgstr "  \\e [SOUBOR] [ŘÁDEK]    editace aktuálního dotazu (nebo souboru) v externím editoru\n"
 
 #: help.c:198
 #, c-format
 msgid "  \\ef [FUNCNAME [LINE]]  edit function definition with external editor\n"
-msgstr "  \\ef [JMENOFUNKCE [ŘÁDEK]]      editace definice funkce v externím editoru\n"
+msgstr "  \\ef [JMENOFUNKCE [ŘÁDEK]] editace definice funkce v externím editoru\n"
 
 #: help.c:199
 #, c-format
 msgid "  \\ev [VIEWNAME [LINE]]  edit view definition with external editor\n"
-msgstr ""
-"  \\ev [VIEWNAME [LINE]]  editace definice pohledu v externím editoru\n"
-"\n"
+msgstr "  \\ev [VIEWNAME [LINE]]  editace definice pohledu v externím editoru\n"
 
 #: help.c:200
 #, c-format
@@ -2799,7 +2797,7 @@ msgstr "  \\copy ...              provede SQL COPY s tokem dat na klienta\n"
 #, c-format
 msgid "  \\echo [-n] [STRING]    write string to standard output (-n for no newline)\n"
 msgstr ""
-"  \\echo [-n] [ŘETĚZEC]    vypsání textu na standardní výstup (-n pro potlačení\n"
+"  \\echo [-n] [ŘETĚZEC]   vypsání textu na standardní výstup (-n pro potlačení\n"
 "                         nového řádku)\n"
 
 #: help.c:211
@@ -2829,7 +2827,7 @@ msgstr ""
 #| msgid "  \\echo [STRING]         write string to standard output\n"
 msgid "  \\warn [-n] [STRING]    write string to standard error (-n for no newline)\n"
 msgstr ""
-"  \\warn [-n] [TEXT]    vypsání textu na standardní výstup (-n pro potlačení\n"
+"  \\warn [-n] [TEXT]      vypsání textu na standardní výstup (-n pro potlačení\n"
 "                         nového řádku)\n"
 
 #: help.c:218
@@ -2907,8 +2905,8 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   vypíše operátory pro rodiny operátor
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   vypíše support funkce rodin operátorů\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   vypíše support funkce rodin operátorů\n"
 
 #: help.c:235
 #, c-format
@@ -2938,7 +2936,7 @@ msgstr "  \\dD[S+] [PATTERN]      seznam domén\n"
 #: help.c:240
 #, c-format
 msgid "  \\ddp    [PATTERN]      list default privileges\n"
-msgstr "  \\ddp     [VZOR]         seznam implicitních privilegií\n"
+msgstr "  \\ddp    [VZOR]         seznam implicitních privilegií\n"
 
 #: help.c:241
 #, c-format
@@ -2973,7 +2971,7 @@ msgstr "  \\df[anptw][S+] [VZOR]  seznam [pouze agg/normal/procedures/trigger/wi
 #: help.c:247
 #, c-format
 msgid "  \\dF[+]  [PATTERN]      list text search configurations\n"
-msgstr "  \\dF[+]   [VZOR]        seznam konfigurací fulltextového vyhledávání\n"
+msgstr "  \\dF[+]  [VZOR]         seznam konfigurací fulltextového vyhledávání\n"
 
 #: help.c:248
 #, c-format
@@ -3022,13 +3020,13 @@ msgstr "  \\dn[S+] [VZOR]         seznam schémat\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [VZOR]         seznam operátorů\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [VZOR]         seznam operátorů\n"
 
 #: help.c:258
 #, c-format
 msgid "  \\dO[S+] [PATTERN]      list collations\n"
-msgstr "  \\dO[S+]  [VZOR]         seznam collations\n"
+msgstr "  \\dO[S+] [VZOR]         seznam collations\n"
 
 #: help.c:259
 #, c-format
@@ -3043,7 +3041,7 @@ msgstr "  \\dP[itn+] [PATTERN]    seznam [pouze index/table] partitioned relatio
 #: help.c:261
 #, c-format
 msgid "  \\drds [PATRN1 [PATRN2]] list per-database role settings\n"
-msgstr "  \\drds [VZOR1 [VZOR2]] seznam nastavení rolí pro jednotlivé databáze\n"
+msgstr "  \\drds [VZOR1 [VZOR2]]  seznam nastavení rolí pro jednotlivé databáze\n"
 
 #: help.c:262
 #, c-format
@@ -3087,8 +3085,8 @@ msgstr "  \\dx[+]  [VZOR]         seznam rozšíření\n"
 
 #: help.c:270
 #, c-format
-msgid "  \\dy     [PATTERN]      list event triggers\n"
-msgstr "  \\dy     [PATTERN]      seznam event triggerů\n"
+msgid "  \\dy[+]  [PATTERN]      list event triggers\n"
+msgstr "  \\dy[+]  [PATTERN]      seznam event triggerů\n"
 
 #: help.c:271
 #, c-format
@@ -3180,7 +3178,7 @@ msgid ""
 "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}\n"
 "                         connect to new database (currently \"%s\")\n"
 msgstr ""
-" \\c[onnect] [DATABÁZE|- UŽIVATEL|- HOST|- PORT|-] | conninfo]\n"
+"  \\c[onnect] [DATABÁZE|- UŽIVATEL|- HOST|- PORT|-] | conninfo]\n"
 "                         připojí se do nové databáze (současná \"%s\")\n"
 
 #: help.c:303
diff --git a/src/bin/psql/po/de.po b/src/bin/psql/po/de.po
index 82e760d7f1..5fd83e3673 100644
--- a/src/bin/psql/po/de.po
+++ b/src/bin/psql/po/de.po
@@ -2911,8 +2911,8 @@ msgstr "  \\dAo[+] [AMMUST [OPFMUST]]   Operatoren in Operatorfamilien auflisten
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMMUST [OPFMUST]]   Unterst.funktionen in Operatorfamilien auflisten\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMMUST [OPFMUST]]   Unterst.funktionen in Operatorfamilien auflisten\n"
 
 #: help.c:235
 #, c-format
@@ -3028,8 +3028,8 @@ msgstr "  \\dn[S+] [MUSTER]       Schemas auflisten\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [MUSTER]       Operatoren auflisten\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [MUSTER]       Operatoren auflisten\n"
 
 #: help.c:258
 #, c-format
@@ -3097,8 +3097,8 @@ msgstr "  \\dx[+]  [MUSTER]       Erweiterungen auflisten\n"
 
 #: help.c:270
 #, c-format
-msgid "  \\dy     [PATTERN]      list event triggers\n"
-msgstr "  \\dy     [MUSTER]       Ereignistrigger auflisten\n"
+msgid "  \\dy[+]  [PATTERN]      list event triggers\n"
+msgstr "  \\dy[+]  [MUSTER]       Ereignistrigger auflisten\n"
 
 #: help.c:271
 #, c-format
diff --git a/src/bin/psql/po/es.po b/src/bin/psql/po/es.po
index e4ac33b6a8..16580e7c41 100644
--- a/src/bin/psql/po/es.po
+++ b/src/bin/psql/po/es.po
@@ -2697,7 +2697,7 @@ msgstr ""
 #: help.c:180
 #, c-format
 msgid "  \\gdesc                 describe result of query, without executing it\n"
-msgstr "  \\gdesc              describir resultado de la consulta, sin ejecutarla\n"
+msgstr "  \\gdesc          describir resultado de la consulta, sin ejecutarla\n"
 
 #: help.c:181
 #, c-format
@@ -2897,22 +2897,22 @@ msgstr "  \\dA[+]  [PATRÓN]  listar métodos de acceso\n"
 #: help.c:231
 #, c-format
 msgid "  \\dAc[+] [AMPTRN [TYPEPTRN]]  list operator classes\n"
-msgstr "  \\do[S]  [PATRÓN]  listar las clases de operadores\n"
+msgstr "  \\dAc[+] [AMPTRN [TYPEPTRN]]  listar las clases de operadores\n"
 
 #: help.c:232
 #, c-format
 msgid "  \\dAf[+] [AMPTRN [TYPEPTRN]]  list operator families\n"
-msgstr "  \\do[S]  [PATRÓN]  listar las familias de operadores\n"
+msgstr "  \\dAf[+] [AMPTRN [TYPEPTRN]]  listar las familias de operadores\n"
 
 #: help.c:233
 #, c-format
 msgid "  \\dAo[+] [AMPTRN [OPFPTRN]]   list operators of operator families\n"
-msgstr "  \\do[S]  [PATRÓN]  listar los operadores de la familia de operadores\n"
+msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   listar los operadores de la familia de operadores\n"
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   enumera las funciones de la familia de operadores\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   enumera las funciones de la familia de operadores\n"
 
 #: help.c:235
 #, c-format
@@ -3026,8 +3026,8 @@ msgstr "  \\dn[S+] [PATRÓN]  listar esquemas\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [PATRÓN]  listar operadores\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [PATRÓN]  listar operadores\n"
 
 #: help.c:258
 #, c-format
@@ -3091,13 +3091,13 @@ msgstr "  \\dx[+]  [PATRÓN]  listar extensiones\n"
 
 #: help.c:270
 #, c-format
-msgid "  \\dy     [PATTERN]      list event triggers\n"
-msgstr "  \\dy     [PATRÓN]   listar disparadores por eventos\n"
+msgid "  \\dy[+]  [PATTERN]      list event triggers\n"
+msgstr "  \\dy[+]  [PATRÓN]  listar disparadores por eventos\n"
 
 #: help.c:271
 #, c-format
 msgid "  \\l[+]   [PATTERN]      list databases\n"
-msgstr "  \\l[+]   [PATRÓN]    listar bases de datos\n"
+msgstr "  \\l[+]   [PATRÓN]  listar bases de datos\n"
 
 #: help.c:272
 #, c-format
diff --git a/src/bin/psql/po/fr.po b/src/bin/psql/po/fr.po
index 44d31ca80b..e3c47c3f50 100644
--- a/src/bin/psql/po/fr.po
+++ b/src/bin/psql/po/fr.po
@@ -2724,8 +2724,8 @@ msgstr "Général\n"
 #, c-format
 msgid "  \\copyright             show PostgreSQL usage and distribution terms\n"
 msgstr ""
-"  \\copyright           affiche les conditions d'utilisation et de\n"
-"                       distribution de PostgreSQL\n"
+"  \\copyright             affiche les conditions d'utilisation et de\n"
+"                         distribution de PostgreSQL\n"
 
 #: help.c:176
 #, c-format
@@ -2743,23 +2743,23 @@ msgid ""
 "  \\g [(OPTIONS)] [FILE]  execute query (and send results to file or |pipe);\n"
 "                         \\g with no arguments is equivalent to a semicolon\n"
 msgstr ""
-"  \\g [(OPTIONS)] [FICHIER]  exécute la requête (et envoie les résultats à un fichier ou à |pipe);\n"
-"                         \\g sans arguments est équivalent à un point-virgule\n"
+"  \\g [(OPTIONS)] [FICHIER] exécute la requête (et envoie les résultats à un fichier ou à |pipe);\n"
+"                           \\g sans arguments est équivalent à un point-virgule\n"
 
 #: help.c:180
 #, c-format
 msgid "  \\gdesc                 describe result of query, without executing it\n"
-msgstr "  \\gdesc             décrit le résultat de la requête sans l'exécuter\n"
+msgstr "  \\gdesc                 décrit le résultat de la requête sans l'exécuter\n"
 
 #: help.c:181
 #, c-format
 msgid "  \\gexec                 execute query, then execute each value in its result\n"
-msgstr "  \\gexec             exécute la requête et exécute chaque valeur du résultat\n"
+msgstr "  \\gexec                 exécute la requête et exécute chaque valeur du résultat\n"
 
 #: help.c:182
 #, c-format
 msgid "  \\gset [PREFIX]         execute query and store results in psql variables\n"
-msgstr "  \\gset [PRÉFIXE]    exécute la requête et stocke les résultats dans des variables psql\n"
+msgstr "  \\gset [PRÉFIXE]        exécute la requête et stocke les résultats dans des variables psql\n"
 
 #: help.c:183
 #, c-format
@@ -2769,7 +2769,7 @@ msgstr "  \\gx [(OPTIONS)] [FICHIER] comme \\g, mais force le mode de sortie ét
 #: help.c:184
 #, c-format
 msgid "  \\q                     quit psql\n"
-msgstr "  \\q                   quitte psql\n"
+msgstr "  \\q                     quitte psql\n"
 
 #: help.c:185
 #, c-format
@@ -2800,8 +2800,8 @@ msgstr "  \\? variables           affiche l'aide sur les variables spéciales\n"
 #, c-format
 msgid "  \\h [NAME]              help on syntax of SQL commands, * for all commands\n"
 msgstr ""
-"  \\h [NOM]             aide-mémoire pour les commandes SQL, * pour toutes\n"
-"                       les commandes\n"
+"  \\h [NOM]               aide-mémoire pour les commandes SQL, * pour toutes\n"
+"                         les commandes\n"
 
 #: help.c:196
 #, c-format
@@ -2812,46 +2812,42 @@ msgstr "Tampon de requête\n"
 #, c-format
 msgid "  \\e [FILE] [LINE]       edit the query buffer (or file) with external editor\n"
 msgstr ""
-"  \\e [FICHIER] [LIGNE] édite le tampon de requête ou le fichier avec un\n"
-"                        éditeur externe\n"
+"  \\e [FICHIER] [LIGNE]   édite le tampon de requête ou le fichier avec un\n"
+"                         éditeur externe\n"
 
 #: help.c:198
 #, c-format
 msgid "  \\ef [FUNCNAME [LINE]]  edit function definition with external editor\n"
 msgstr ""
 "  \\ef [FONCTION [LIGNE]] édite la définition de fonction avec un éditeur\n"
-"                        externe\n"
+"                         externe\n"
 
 #: help.c:199
 #, c-format
 msgid "  \\ev [VIEWNAME [LINE]]  edit view definition with external editor\n"
-msgstr ""
-"  \\ev [VUE [LIGNE]]      édite la définition de vue avec un éditeur\n"
-"                        externe\n"
+msgstr "  \\ev [VUE [LIGNE]]      édite la définition de vue avec un éditeur externe\n"
 
 #: help.c:200
 #, c-format
 msgid "  \\p                     show the contents of the query buffer\n"
-msgstr "  \\p                   affiche le contenu du tampon de requête\n"
+msgstr "  \\p                     affiche le contenu du tampon de requête\n"
 
 #: help.c:201
 #, c-format
 msgid "  \\r                     reset (clear) the query buffer\n"
-msgstr "  \\r                   efface le tampon de requêtes\n"
+msgstr "  \\r                     efface le tampon de requêtes\n"
 
 #: help.c:203
 #, c-format
 msgid "  \\s [FILE]              display history or save it to file\n"
-msgstr ""
-"  \\s [FICHIER]         affiche l'historique ou le sauvegarde dans un\n"
-"                       fichier\n"
+msgstr "  \\s [FICHIER]           affiche l'historique ou le sauvegarde dans un fichier\n"
 
 #: help.c:205
 #, c-format
 msgid "  \\w FILE                write query buffer to file\n"
 msgstr ""
-"  \\w [FICHIER]         écrit le contenu du tampon de requêtes dans un\n"
-"                       fichier\n"
+"  \\w FICHIER             écrit le contenu du tampon de requêtes dans un\n"
+"                         fichier\n"
 
 #: help.c:208
 #, c-format
@@ -2862,8 +2858,8 @@ msgstr "Entrée/Sortie\n"
 #, c-format
 msgid "  \\copy ...              perform SQL COPY with data stream to the client host\n"
 msgstr ""
-"  \\copy ...            exécute SQL COPY avec le flux de données dirigé vers\n"
-"                       l'hôte client\n"
+"  \\copy ...              exécute SQL COPY avec le flux de données dirigé vers\n"
+"                         l'hôte client\n"
 
 #: help.c:210
 #, c-format
@@ -2873,28 +2869,28 @@ msgstr "  \\echo [-n] [TEXTE]     écrit le texte sur la sortie standard (-n pou
 #: help.c:211
 #, c-format
 msgid "  \\i FILE                execute commands from file\n"
-msgstr "  \\i FICHIER           exécute les commandes du fichier\n"
+msgstr "  \\i FICHIER             exécute les commandes du fichier\n"
 
 #: help.c:212
 #, c-format
 msgid "  \\ir FILE               as \\i, but relative to location of current script\n"
 msgstr ""
-"  \\ir FICHIER         identique à \\i, mais relatif à l'emplacement du script\n"
-"                       ou un |tube\n"
+"  \\ir FICHIER            identique à \\i, mais relatif à l'emplacement du script\n"
+"                         ou un |tube\n"
 
 #: help.c:213
 #, c-format
 msgid "  \\o [FILE]              send all query results to file or |pipe\n"
 msgstr ""
-"  \\o [FICHIER]         envoie les résultats de la requête vers un fichier\n"
-"                       ou un |tube\n"
+"  \\o [FICHIER]           envoie les résultats de la requête vers un fichier\n"
+"                         ou un |tube\n"
 
 #: help.c:214
 #, c-format
 msgid "  \\qecho [-n] [STRING]   write string to \\o output stream (-n for no newline)\n"
 msgstr ""
 "  \\qecho [-n] [TEXTE]    écrit un texte sur la sortie des résultats des\n"
-"                       requêtes (\\o) (-n pour supprimer le retour à la ligne)\n"
+"                         requêtes (\\o) (-n pour supprimer le retour à la ligne)\n"
 
 #: help.c:215
 #, c-format
@@ -2939,24 +2935,24 @@ msgstr "  (options : S = affiche les objets systèmes, + = informations supplém
 #: help.c:227
 #, c-format
 msgid "  \\d[S+]                 list tables, views, and sequences\n"
-msgstr "  \\d[S+]               affiche la liste des tables, vues et séquences\n"
+msgstr "  \\d[S+]                 affiche la liste des tables, vues et séquences\n"
 
 #: help.c:228
 #, c-format
 msgid "  \\d[S+]  NAME           describe table, view, sequence, or index\n"
 msgstr ""
-"  \\d[S+] NOM           affiche la description de la table, de la vue,\n"
-"                       de la séquence ou de l'index\n"
+"  \\d[S+]  NOM            affiche la description de la table, de la vue,\n"
+"                         de la séquence ou de l'index\n"
 
 #: help.c:229
 #, c-format
 msgid "  \\da[S]  [PATTERN]      list aggregates\n"
-msgstr "  \\da[S] [MODÈLE]      affiche les aggrégats\n"
+msgstr "  \\da[S]  [MODÈLE]       affiche les aggrégats\n"
 
 #: help.c:230
 #, c-format
 msgid "  \\dA[+]  [PATTERN]      list access methods\n"
-msgstr "  \\dA[+] [MODÈLE]      affiche la liste des méthodes d'accès\n"
+msgstr "  \\dA[+]  [MODÈLE]       affiche la liste des méthodes d'accès\n"
 
 #: help.c:231
 #, c-format
@@ -2975,149 +2971,147 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   affiche les opérateurs des familles d'o
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   liste les fonctions de support des familles d'opérateur\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   liste les fonctions de support des familles d'opérateur\n"
 
 #: help.c:235
 #, c-format
 msgid "  \\db[+]  [PATTERN]      list tablespaces\n"
-msgstr "  \\db[+] [MODÈLE]      affiche la liste des tablespaces\n"
+msgstr "  \\db[+]  [MODÈLE]       affiche la liste des tablespaces\n"
 
 #: help.c:236
 #, c-format
 msgid "  \\dc[S+] [PATTERN]      list conversions\n"
-msgstr "  \\dc[S+] [MODÈLE]     affiche la liste des conversions\n"
+msgstr "  \\dc[S+] [MODÈLE]       affiche la liste des conversions\n"
 
 #: help.c:237
 #, c-format
 msgid "  \\dC[+]  [PATTERN]      list casts\n"
-msgstr "  \\dC[+] [MODÈLE]      affiche la liste des transtypages\n"
+msgstr "  \\dC[+]  [MODÈLE]       affiche la liste des transtypages\n"
 
 #: help.c:238
 #, c-format
 msgid "  \\dd[S]  [PATTERN]      show object descriptions not displayed elsewhere\n"
 msgstr ""
-"  \\dd[S] [MODÈLE]      affiche les commentaires des objets dont le commentaire\n"
-"                        n'est affiché nul part ailleurs\n"
+"  \\dd[S]  [MODÈLE]       affiche les commentaires des objets dont le commentaire\n"
+"                         n'est affiché nul part ailleurs\n"
 
 #: help.c:239
 #, c-format
 msgid "  \\dD[S+] [PATTERN]      list domains\n"
-msgstr "  \\dD[S+] [MODÈLE]     affiche la liste des domaines\n"
+msgstr "  \\dD[S+] [MODÈLE]       affiche la liste des domaines\n"
 
 #: help.c:240
 #, c-format
 msgid "  \\ddp    [PATTERN]      list default privileges\n"
-msgstr "  \\ddp   [MODÈLE]      affiche les droits par défaut\n"
+msgstr "  \\ddp    [MODÈLE]       affiche les droits par défaut\n"
 
 #: help.c:241
 #, c-format
 msgid "  \\dE[S+] [PATTERN]      list foreign tables\n"
-msgstr "  \\dE[S+] [MODÈLE]     affiche la liste des tables distantes\n"
+msgstr "  \\dE[S+] [MODÈLE]       affiche la liste des tables distantes\n"
 
 #: help.c:242
 #, c-format
 msgid "  \\det[+] [PATTERN]      list foreign tables\n"
-msgstr "  \\det[+] [MODÈLE]     affiche la liste des tables distantes\n"
+msgstr "  \\det[+] [MODÈLE]       affiche la liste des tables distantes\n"
 
 #: help.c:243
 #, c-format
 msgid "  \\des[+] [PATTERN]      list foreign servers\n"
-msgstr "  \\des[+] [MODÈLE]     affiche la liste des serveurs distants\n"
+msgstr "  \\des[+] [MODÈLE]       affiche la liste des serveurs distants\n"
 
 #: help.c:244
 #, c-format
 msgid "  \\deu[+] [PATTERN]      list user mappings\n"
-msgstr "  \\deu[+] [MODÈLE]     affiche la liste des correspondances utilisateurs\n"
+msgstr "  \\deu[+] [MODÈLE]       affiche la liste des correspondances utilisateurs\n"
 
 #: help.c:245
 #, c-format
 msgid "  \\dew[+] [PATTERN]      list foreign-data wrappers\n"
-msgstr "  \\dew[+] [MODÈLE]     affiche la liste des wrappers de données distantes\n"
+msgstr "  \\dew[+] [MODÈLE]       affiche la liste des wrappers de données distantes\n"
 
 #: help.c:246
 #, c-format
 msgid "  \\df[anptw][S+] [PATRN] list [only agg/normal/procedures/trigger/window] functions\n"
 msgstr ""
 "  \\df[anptw][S+] [PATRN] affiche la liste des fonctions\n"
-"                        [seulement agrégat/normal/procédure/trigger/window]\n"
+"                         [seulement agrégat/normal/procédure/trigger/window]\n"
 
 #: help.c:247
 #, c-format
 msgid "  \\dF[+]  [PATTERN]      list text search configurations\n"
 msgstr ""
-"  \\dF[+] [MODÈLE]      affiche la liste des configurations de la recherche\n"
-"                        plein texte\n"
+"  \\dF[+]  [MODÈLE]       affiche la liste des configurations de la recherche\n"
+"                         plein texte\n"
 
 #: help.c:248
 #, c-format
 msgid "  \\dFd[+] [PATTERN]      list text search dictionaries\n"
 msgstr ""
-"  \\dFd[+] [MODÈLE]     affiche la liste des dictionnaires de la recherche de\n"
-"                        texte\n"
+"  \\dFd[+] [MODÈLE]       affiche la liste des dictionnaires de la recherche de\n"
+"                         texte\n"
 
 #: help.c:249
 #, c-format
 msgid "  \\dFp[+] [PATTERN]      list text search parsers\n"
 msgstr ""
-"  \\dFp[+] [MODÈLE]        affiche la liste des analyseurs de la recherche de\n"
-"                       texte\n"
+"  \\dFp[+] [MODÈLE]       affiche la liste des analyseurs de la recherche de\n"
+"                         texte\n"
 
 #: help.c:250
 #, c-format
 msgid "  \\dFt[+] [PATTERN]      list text search templates\n"
-msgstr ""
-"  \\dFt[+] [MODÈLE]     affiche la liste des modèles de la recherche de\n"
-"                        texte\n"
+msgstr "  \\dFt[+] [MODÈLE]       affiche la liste des modèles de la recherche de texte\n"
 
 #: help.c:251
 #, c-format
 msgid "  \\dg[S+] [PATTERN]      list roles\n"
-msgstr "  \\dg[S+]  [MODÈLE]    affiche la liste des rôles (utilisateurs)\n"
+msgstr "  \\dg[S+] [MODÈLE]       affiche la liste des rôles (utilisateurs)\n"
 
 #: help.c:252
 #, c-format
 msgid "  \\di[S+] [PATTERN]      list indexes\n"
-msgstr "  \\di[S+] [MODÈLE]     affiche la liste des index\n"
+msgstr "  \\di[S+] [MODÈLE]       affiche la liste des index\n"
 
 #: help.c:253
 #, c-format
 msgid "  \\dl                    list large objects, same as \\lo_list\n"
 msgstr ""
-"  \\dl                  affiche la liste des « Large Objects », identique à\n"
-"                        \\lo_list\n"
+"  \\dl                    affiche la liste des « Large Objects », identique à\n"
+"                         \\lo_list\n"
 
 #: help.c:254
 #, c-format
 msgid "  \\dL[S+] [PATTERN]      list procedural languages\n"
-msgstr "  \\dL[S+] [MODÈLE]     affiche la liste des langages procéduraux\n"
+msgstr "  \\dL[S+] [MODÈLE]       affiche la liste des langages procéduraux\n"
 
 #: help.c:255
 #, c-format
 msgid "  \\dm[S+] [PATTERN]      list materialized views\n"
-msgstr "  \\dm[S+] [MODÈLE]     affiche la liste des vues matérialisées\n"
+msgstr "  \\dm[S+] [MODÈLE]       affiche la liste des vues matérialisées\n"
 
 #: help.c:256
 #, c-format
 msgid "  \\dn[S+] [PATTERN]      list schemas\n"
-msgstr "  \\dn[S+]  [MODÈLE]    affiche la liste des schémas\n"
+msgstr "  \\dn[S+] [MODÈLE]       affiche la liste des schémas\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [MODÈLE]     affiche la liste des opérateurs\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [MODÈLE]       affiche la liste des opérateurs\n"
 
 #: help.c:258
 #, c-format
 msgid "  \\dO[S+] [PATTERN]      list collations\n"
-msgstr "  \\dO[S+] [MODÈLE]     affiche la liste des collationnements\n"
+msgstr "  \\dO[S+] [MODÈLE]       affiche la liste des collationnements\n"
 
 #: help.c:259
 #, c-format
 msgid "  \\dp     [PATTERN]      list table, view, and sequence access privileges\n"
 msgstr ""
-"  \\dp     [MODÈLE]     affiche la liste des droits d'accès aux tables,\n"
-"                        vues, séquences\n"
+"  \\dp     [MODÈLE]       affiche la liste des droits d'accès aux tables,\n"
+"                         vues, séquences\n"
 
 #: help.c:260
 #, c-format
@@ -3127,72 +3121,72 @@ msgstr "  \\dP[itn+] [PATTERN]    affiche les relations partitionnées [seulemen
 #: help.c:261
 #, c-format
 msgid "  \\drds [PATRN1 [PATRN2]] list per-database role settings\n"
-msgstr "  \\drds [MODEL1 [MODEL2]] liste la configuration utilisateur par base de                           données\n"
+msgstr "  \\drds [MODEL1 [MODEL2]] liste la configuration utilisateur par base de données\n"
 
 #: help.c:262
 #, c-format
 msgid "  \\dRp[+] [PATTERN]      list replication publications\n"
-msgstr "  \\dRp[S+] [MODÈLE]    affiche la liste des publications de réplication\n"
+msgstr "  \\dRp[S+] [MODÈLE]      affiche la liste des publications de réplication\n"
 
 #: help.c:263
 #, c-format
 msgid "  \\dRs[+] [PATTERN]      list replication subscriptions\n"
-msgstr "  \\dRs[+] [MODÈLE]     affiche la liste des souscriptions de réplication\n"
+msgstr "  \\dRs[+] [MODÈLE]       affiche la liste des souscriptions de réplication\n"
 
 #: help.c:264
 #, c-format
 msgid "  \\ds[S+] [PATTERN]      list sequences\n"
-msgstr "  \\ds[S+] [MODÈLE]     affiche la liste des séquences\n"
+msgstr "  \\ds[S+] [MODÈLE]       affiche la liste des séquences\n"
 
 #: help.c:265
 #, c-format
 msgid "  \\dt[S+] [PATTERN]      list tables\n"
-msgstr "  \\dt[S+] [MODÈLE]     affiche la liste des tables\n"
+msgstr "  \\dt[S+] [MODÈLE]       affiche la liste des tables\n"
 
 #: help.c:266
 #, c-format
 msgid "  \\dT[S+] [PATTERN]      list data types\n"
-msgstr "  \\dT[S+] [MODÈLE]     affiche la liste des types de données\n"
+msgstr "  \\dT[S+] [MODÈLE]       affiche la liste des types de données\n"
 
 #: help.c:267
 #, c-format
 msgid "  \\du[S+] [PATTERN]      list roles\n"
-msgstr "  \\du[S+]  [MODÈLE]    affiche la liste des rôles (utilisateurs)\n"
+msgstr "  \\du[S+] [MODÈLE]       affiche la liste des rôles (utilisateurs)\n"
 
 #: help.c:268
 #, c-format
 msgid "  \\dv[S+] [PATTERN]      list views\n"
-msgstr "  \\dv[S+] [MODÈLE]     affiche la liste des vues\n"
+msgstr "  \\dv[S+] [MODÈLE]       affiche la liste des vues\n"
 
 #: help.c:269
 #, c-format
 msgid "  \\dx[+]  [PATTERN]      list extensions\n"
-msgstr "  \\dx[+] [MODÈLE]      affiche la liste des extensions\n"
+msgstr "  \\dx[+]  [MODÈLE]       affiche la liste des extensions\n"
 
 #: help.c:270
 #, c-format
-msgid "  \\dy     [PATTERN]      list event triggers\n"
-msgstr "  \\dy   [MODÈLE]      affiche les triggers sur évènement\n"
+msgid "  \\dy[+]  [PATTERN]      list event triggers\n"
+msgstr "  \\dy[+]  [MODÈLE]       affiche les triggers sur évènement\n"
 
 #: help.c:271
 #, c-format
 msgid "  \\l[+]   [PATTERN]      list databases\n"
-msgstr "  \\l[+] [MODÈLE]     affiche la liste des bases de données\n"
+msgstr "  \\l[+]   [MODÈLE]       affiche la liste des bases de données\n"
 
 #: help.c:272
 #, c-format
 msgid "  \\sf[+]  FUNCNAME       show a function's definition\n"
-msgstr "  \\sf[+] [FONCTION]    édite la définition d'une fonction\n"
+msgstr "  \\sf[+]  FONCTION       édite la définition d'une fonction\n"
 
 #: help.c:273
 #, c-format
 msgid "  \\sv[+]  VIEWNAME       show a view's definition\n"
-msgstr "  \\sv [FONCTION]       édite la définition d'une vue\n"
+msgstr "  \\sv[+]  VUE            édite la définition d'une vue\n"
 
 #: help.c:274
 #, c-format
 msgid "  \\z      [PATTERN]      same as \\dp\n"
-msgstr "  \\z      [MODÈLE]     identique à \\dp\n"
+msgstr "  \\z      [MODÈLE]       identique à \\dp\n"
 
 #: help.c:277
 #, c-format
@@ -3203,27 +3197,27 @@ msgstr "Formatage\n"
 #, c-format
 msgid "  \\a                     toggle between unaligned and aligned output mode\n"
 msgstr ""
-"  \\a                   bascule entre les modes de sortie alignée et non\n"
-"                        alignée\n"
+"  \\a                     bascule entre les modes de sortie alignée et non\n"
+"                         alignée\n"
 
 #: help.c:279
 #, c-format
 msgid "  \\C [STRING]            set table title, or unset if none\n"
 msgstr ""
-"  \\C [CHAÎNE]          initialise le titre d'une table, ou le désactive en\n"
-"                        l'absence d'argument\n"
+"  \\C [CHAÎNE]            initialise le titre d'une table, ou le désactive en\n"
+"                         l'absence d'argument\n"
 
 #: help.c:280
 #, c-format
 msgid "  \\f [STRING]            show or set field separator for unaligned query output\n"
 msgstr ""
-"  \\f [CHAÎNE]          affiche ou initialise le séparateur de champ pour\n"
-"                        une sortie non alignée des requêtes\n"
+"  \\f [CHAÎNE]            affiche ou initialise le séparateur de champ pour\n"
+"                         une sortie non alignée des requêtes\n"
 
 #: help.c:281
 #, c-format
 msgid "  \\H                     toggle HTML output mode (currently %s)\n"
-msgstr "  \\H                   bascule le mode de sortie HTML (actuellement %s)\n"
+msgstr "  \\H                     bascule le mode de sortie HTML (actuellement %s)\n"
 
 #: help.c:283
 #, c-format
@@ -3247,19 +3241,19 @@ msgstr ""
 #: help.c:290
 #, c-format
 msgid "  \\t [on|off]            show only rows (currently %s)\n"
-msgstr "  \\t                   affiche uniquement les lignes (actuellement %s)\n"
+msgstr "  \\t [on|off]            affiche uniquement les lignes (actuellement %s)\n"
 
 #: help.c:292
 #, c-format
 msgid "  \\T [STRING]            set HTML <table> tag attributes, or unset if none\n"
 msgstr ""
-"  \\T [CHAÎNE]          initialise les attributs HTML de la balise <table>,\n"
-"                        ou l'annule en l'absence d'argument\n"
+"  \\T [CHAÎNE]            initialise les attributs HTML de la balise <table>,\n"
+"                         ou l'annule en l'absence d'argument\n"
 
 #: help.c:293
 #, c-format
 msgid "  \\x [on|off|auto]       toggle expanded output (currently %s)\n"
-msgstr "  \\x [on|off|auto]     bascule l'affichage étendu (actuellement %s)\n"
+msgstr "  \\x [on|off|auto]       bascule l'affichage étendu (actuellement %s)\n"
 
 #: help.c:297
 #, c-format
@@ -3273,8 +3267,8 @@ msgid ""
 "                         connect to new database (currently \"%s\")\n"
 msgstr ""
 "  \\c[onnect] {[NOM_BASE|- UTILISATEUR|- HOTE|- PORT|-] | conninfo}\n"
-"                        se connecte à une autre base de données\n"
-"                        (actuellement « %s »)\n"
+"                         se connecte à une autre base de données\n"
+"                         (actuellement « %s »)\n"
 
 #: help.c:303
 #, c-format
@@ -3289,20 +3283,20 @@ msgstr ""
 #: help.c:305
 #, c-format
 msgid "  \\conninfo              display information about current connection\n"
-msgstr "  \\conninfo            affiche des informations sur la connexion en cours\n"
+msgstr "  \\conninfo              affiche des informations sur la connexion en cours\n"
 
 #: help.c:306
 #, c-format
 msgid "  \\encoding [ENCODING]   show or set client encoding\n"
-msgstr "  \\encoding [ENCODAGE] affiche ou initialise l'encodage du client\n"
+msgstr "  \\encoding [ENCODAGE]   affiche ou initialise l'encodage du client\n"
 
 #: help.c:307
 #, c-format
 msgid "  \\password [USERNAME]   securely change the password for a user\n"
 msgstr ""
 "  \\password [UTILISATEUR]\n"
-"                        modifie de façon sécurisé le mot de passe d'un\n"
-"                        utilisateur\n"
+"                         modifie de façon sécurisé le mot de passe d'un\n"
+"                         utilisateur\n"
 
 #: help.c:310
 #, c-format
@@ -3312,26 +3306,26 @@ msgstr "Système d'exploitation\n"
 #: help.c:311
 #, c-format
 msgid "  \\cd [DIR]              change the current working directory\n"
-msgstr "  \\cd [RÉPERTOIRE]     change de répertoire de travail\n"
+msgstr "  \\cd [RÉPERTOIRE]       change de répertoire de travail\n"
 
 #: help.c:312
 #, c-format
 msgid "  \\setenv NAME [VALUE]   set or unset environment variable\n"
-msgstr "  \\setenv NOM [VALEUR] (dés)initialise une variable d'environnement\n"
+msgstr "  \\setenv NOM [VALEUR]   (dés)initialise une variable d'environnement\n"
 
 #: help.c:313
 #, c-format
 msgid "  \\timing [on|off]       toggle timing of commands (currently %s)\n"
 msgstr ""
-"  \\timing [on|off]     bascule l'activation du chronométrage des commandes\n"
-"                        (actuellement %s)\n"
+"  \\timing [on|off]       bascule l'activation du chronométrage des commandes\n"
+"                         (actuellement %s)\n"
 
 #: help.c:315
 #, c-format
 msgid "  \\! [COMMAND]           execute command in shell or start interactive shell\n"
 msgstr ""
-"  \\! [COMMANDE]        exécute la commande dans un shell ou exécute un\n"
-"                        shell interactif\n"
+"  \\! [COMMANDE]          exécute la commande dans un shell ou exécute un\n"
+"                         shell interactif\n"
 
 #: help.c:318
 #, c-format
@@ -3342,20 +3336,20 @@ msgstr "Variables\n"
 #, c-format
 msgid "  \\prompt [TEXT] NAME    prompt user to set internal variable\n"
 msgstr ""
-"  \\prompt [TEXTE] NOM  demande à l'utilisateur de configurer la variable\n"
-"                        interne\n"
+"  \\prompt [TEXTE] NOM    demande à l'utilisateur de configurer la variable\n"
+"                         interne\n"
 
 #: help.c:320
 #, c-format
 msgid "  \\set [NAME [VALUE]]    set internal variable, or list all if no parameters\n"
 msgstr ""
-"  \\set [NOM [VALEUR]]  initialise une variable interne ou les affiche\n"
-"                        toutes en l'absence de paramètre\n"
+"  \\set [NOM [VALEUR]]    initialise une variable interne ou les affiche\n"
+"                         toutes en l'absence de paramètre\n"
 
 #: help.c:321
 #, c-format
 msgid "  \\unset NAME            unset (delete) internal variable\n"
-msgstr "  \\unset NOM           désactive (supprime) la variable interne\n"
+msgstr "  \\unset NOM             désactive (supprime) la variable interne\n"
 
 #: help.c:324
 #, c-format
@@ -3373,8 +3367,7 @@ msgstr ""
 "  \\lo_export OIDLOB FICHIER\n"
 "  \\lo_import FICHIER [COMMENTAIRE]\n"
 "  \\lo_list\n"
-"  \\lo_unlink OIDLOB\n"
-"                        opérations sur les « Large Objects »\n"
+"  \\lo_unlink OIDLOB      opérations sur les « Large Objects »\n"
 
 #: help.c:352
 #, c-format
diff --git a/src/bin/psql/po/it.po b/src/bin/psql/po/it.po
index 58d5e381f9..fefb4dd5b0 100644
--- a/src/bin/psql/po/it.po
+++ b/src/bin/psql/po/it.po
@@ -2759,12 +2759,12 @@ msgstr "  \\dm[S+] [PATTERN]      elenca le viste materializzate\n"
 #: help.c:248
 #, c-format
 msgid "  \\dn[S+] [PATTERN]      list schemas\n"
-msgstr "  \\dn[S+]  [MODELLO]     elenca gli schemi\n"
+msgstr "  \\dn[S+] [MODELLO]      elenca gli schemi\n"
 
 #: help.c:249
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [MODELLO]      elenca gli operatori\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [MODELLO]      elenca gli operatori\n"
 
 #: help.c:250
 #, c-format
@@ -3018,7 +3018,7 @@ msgstr ""
 "  \\lo_export LOBOID FILE\n"
 "  \\lo_import FILE [COMMENTO] \n"
 "  \\lo_list\n"
-"  \\lo_unlink LOBOID    operazioni sui large object\n"
+"  \\lo_unlink LOBOID      operazioni sui large object\n"
 
 #: help.c:342
 #, c-format
diff --git a/src/bin/psql/po/ja.po b/src/bin/psql/po/ja.po
index f33e5e97f4..7fe5df8c00 100644
--- a/src/bin/psql/po/ja.po
+++ b/src/bin/psql/po/ja.po
@@ -2895,8 +2895,8 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   演算子族の演算子の一覧を表
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   演算子族のサポート関数の一覧を表示\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   演算子族のサポート関数の一覧を表示\n"
 
 #: help.c:235
 #, c-format
@@ -2916,7 +2916,7 @@ msgstr "  \\dC[+]  [パターン]     キャストの一覧を表示します。
 #: help.c:238
 #, c-format
 msgid "  \\dd[S]  [PATTERN]      show object descriptions not displayed elsewhere\n"
-msgstr "  \\dd[S] [パターン]      他では表示されないオブジェクトの説明を表示\n"
+msgstr "  \\dd[S]  [パターン]     他では表示されないオブジェクトの説明を表示\n"
 
 #: help.c:239
 #, c-format
@@ -3012,8 +3012,8 @@ msgstr "  \\dn[S+] [パターン]     スキーマの一覧を表示\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [名前]         演算子の一覧を表示\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [名前]         演算子の一覧を表示\n"
 
 #: help.c:258
 #, c-format
diff --git a/src/bin/psql/po/ko.po b/src/bin/psql/po/ko.po
index 3d3da974b6..78b2fa77d7 100644
--- a/src/bin/psql/po/ko.po
+++ b/src/bin/psql/po/ko.po
@@ -3008,9 +3008,9 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   연산자 부류 소속 연산자 목록
 #: help.c:234
 #, c-format
 msgid ""
-"  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+"  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
 msgstr ""
-"  \\dAp    [AMPTRN [OPFPTRN]]   연산자 가족에 포함된 지원 함수 목록\n"
+"  \\dAp[+] [AMPTRN [OPFPTRN]]   연산자 가족에 포함된 지원 함수 목록\n"
 
 #: help.c:235
 #, c-format
@@ -3129,8 +3129,8 @@ msgstr "  \\dn[S+] [PATTERN]      스키마 목록\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [PATTERN]      연산자 목록\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [PATTERN]      연산자 목록\n"
 
 #: help.c:258
 #, c-format
@@ -3214,7 +3214,7 @@ msgstr "  \\sf[+]  함수이름       함수 정의 보기\n"
 #: help.c:273
 #, c-format
 msgid "  \\sv[+]  VIEWNAME       show a view's definition\n"
-msgstr "  \\sv[+] 뷰이름          뷰 정의 보기\n"
+msgstr "  \\sv[+]  뷰이름         뷰 정의 보기\n"
 
 #: help.c:274
 #, c-format
diff --git a/src/bin/psql/po/ru.po b/src/bin/psql/po/ru.po
index 5e6303c655..cd397a71cc 100644
--- a/src/bin/psql/po/ru.po
+++ b/src/bin/psql/po/ru.po
@@ -3116,9 +3116,9 @@ msgstr ""
 #: help.c:234
 #, c-format
 msgid ""
-"  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+"  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
 msgstr ""
-"  \\dAp    [МСК_МД [МСК_СОП]]   список опорных функций из семейств "
+"  \\dAp[+] [МСК_МД [МСК_СОП]]   список опорных функций из семейств "
 "операторов\n"
 
 #: help.c:235
@@ -3240,8 +3240,8 @@ msgstr "  \\dn[S+] [МАСКА]        список схем\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [МАСКА]        список операторов\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [МАСКА]        список операторов\n"
 
 #: help.c:258
 #, c-format
diff --git a/src/bin/psql/po/sv.po b/src/bin/psql/po/sv.po
index 3d783d72fd..18b6302482 100644
--- a/src/bin/psql/po/sv.po
+++ b/src/bin/psql/po/sv.po
@@ -2887,8 +2887,8 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]  lista operatorer i operatorfamiljer\n"
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   lista supportfunktioner i operatorfamiljer\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   lista supportfunktioner i operatorfamiljer\n"
 
 #: help.c:235
 #, c-format
@@ -2898,7 +2898,7 @@ msgstr "  \\db[+]  [MALL]         lista tabellutrymmen\n"
 #: help.c:236
 #, c-format
 msgid "  \\dc[S+] [PATTERN]      list conversions\n"
-msgstr "  \\dc[S+]  [MALL]        lista konverteringar\n"
+msgstr "  \\dc[S+] [MALL]         lista konverteringar\n"
 
 #: help.c:237
 #, c-format
@@ -2913,12 +2913,12 @@ msgstr "  \\dd[S]  [MALL]         visa objektbeskrivning som inte visas på andr
 #: help.c:239
 #, c-format
 msgid "  \\dD[S+] [PATTERN]      list domains\n"
-msgstr "  \\dD[S+]  [MALL]        lista domäner\n"
+msgstr "  \\dD[S+] [MALL]         lista domäner\n"
 
 #: help.c:240
 #, c-format
 msgid "  \\ddp    [PATTERN]      list default privileges\n"
-msgstr "  \\ddp     [MALL]        lista standardrättigheter\n"
+msgstr "  \\ddp    [MALL]         lista standardrättigheter\n"
 
 #: help.c:241
 #, c-format
@@ -3002,8 +3002,8 @@ msgstr "  \\dn[S+] [MALL]         lista scheman\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [MALL]         lista operatorer\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [MALL]         lista operatorer\n"
 
 #: help.c:258
 #, c-format
diff --git a/src/bin/psql/po/tr.po b/src/bin/psql/po/tr.po
index 0096ffb0ed..18b9b3d616 100644
--- a/src/bin/psql/po/tr.po
+++ b/src/bin/psql/po/tr.po
@@ -2745,12 +2745,12 @@ msgstr "  \\r                     sorgu tamponunu sıfırla (temizle)\n"
 #: help.c:202
 #, c-format
 msgid "  \\s [FILE]              display history or save it to file\n"
-msgstr "  \\s [DOSYA]              geçmişi göster ya da  dosyaya kaydet\n"
+msgstr "  \\s [DOSYA]             geçmişi göster ya da  dosyaya kaydet\n"
 
 #: help.c:204
 #, c-format
 msgid "  \\w FILE                write query buffer to file\n"
-msgstr "  \\w DOSYA            sorgu tamponunu dosyaya kaydet\n"
+msgstr "  \\w DOSYA               sorgu tamponunu dosyaya kaydet\n"
 
 #: help.c:207
 #, c-format
@@ -2770,17 +2770,17 @@ msgstr "  \\echo [METIN]           standart çıktıya bir satır gönder\n"
 #: help.c:210
 #, c-format
 msgid "  \\i FILE                execute commands from file\n"
-msgstr "  \\i DOSYA                dosyadaki komutları çalıştıre\n"
+msgstr "  \\i DOSYA               dosyadaki komutları çalıştıre\n"
 
 #: help.c:211
 #, c-format
 msgid "  \\ir FILE               as \\i, but relative to location of current script\n"
-msgstr "  \\ir DOSYA               \\i gibi, fakat geçerli betiğin bulunduğu yere göre\n"
+msgstr "  \\ir DOSYA              \\i gibi, fakat geçerli betiğin bulunduğu yere göre\n"
 
 #: help.c:212
 #, c-format
 msgid "  \\o [FILE]              send all query results to file or |pipe\n"
-msgstr "  \\o [DOSYA]            tüm sorgu sonuçlarını dosyaya ya da |pipe'e gönder\n"
+msgstr "  \\o [DOSYA]             tüm sorgu sonuçlarını dosyaya ya da |pipe'e gönder\n"
 
 #: help.c:213
 #, c-format
@@ -2800,7 +2800,7 @@ msgstr "  \\if EXPR               şartlı bloğa başla\n"
 #: help.c:218
 #, c-format
 msgid "  \\elif EXPR             alternative within current conditional block\n"
-msgstr "  \\elif EXPR              geçerli şartlı blok içinde alternatif\n"
+msgstr "  \\elif EXPR             geçerli şartlı blok içinde alternatif\n"
 
 #: help.c:219
 #, c-format
@@ -2830,7 +2830,7 @@ msgstr "  \\d[S+]                 tablo, views, ve sequenceleri listele\n"
 #: help.c:226
 #, c-format
 msgid "  \\d[S+]  NAME           describe table, view, sequence, or index\n"
-msgstr "  \\d[S+}  AD                tablo, indeks, sequence, ya da view tanımlarını göster\n"
+msgstr "  \\d[S+]  AD             tablo, indeks, sequence, ya da view tanımlarını göster\n"
 
 #: help.c:227
 #, c-format
@@ -2850,7 +2850,7 @@ msgstr "  \\db[+]  [PATTERN]      tablespaceleri listele\n"
 #: help.c:230
 #, c-format
 msgid "  \\dc[S+] [PATTERN]      list conversions\n"
-msgstr "  \\dc[S+]  [PATTERN]      dönüşümleri listele\n"
+msgstr "  \\dc[S+] [PATTERN]      dönüşümleri listele\n"
 
 #: help.c:231
 #, c-format
@@ -2865,7 +2865,7 @@ msgstr "  \\dd[S]  [PATTERN]      başka yerde gösterilmeyen nesne açıklamala
 #: help.c:233
 #, c-format
 msgid "  \\dD[S+] [PATTERN]      list domains\n"
-msgstr "  \\dD[S+] [PATTERN]     domainleri listele\n"
+msgstr "  \\dD[S+] [PATTERN]      domainleri listele\n"
 
 #: help.c:234
 #, c-format
@@ -2926,7 +2926,7 @@ msgstr "  \\dFt[+] [PATTERN]      metin arama şablonlarını listele\n"
 #: help.c:245
 #, c-format
 msgid "  \\dg[S+] [PATTERN]      list roles\n"
-msgstr "   \\dg[S+] [PATTERN]      rolleri listele\n"
+msgstr "  \\dg[S+] [PATTERN]      rolleri listele\n"
 
 #: help.c:246
 #, c-format
@@ -2946,22 +2946,22 @@ msgstr "  \\dL[S+] [PATTERN]      yordamsal dilleri listele\n"
 #: help.c:249
 #, c-format
 msgid "  \\dm[S+] [PATTERN]      list materialized views\n"
-msgstr "   \\dm[S+] [PATTERN]      maddileştirilmiş görünümleri (materialized view) listele\n"
+msgstr "  \\dm[S+] [PATTERN]      maddileştirilmiş görünümleri (materialized view) listele\n"
 
 #: help.c:250
 #, c-format
 msgid "  \\dn[S+] [PATTERN]      list schemas\n"
-msgstr "  \\dn[S+]  [PATTERN]      şemaları listele\n"
+msgstr "  \\dn[S+] [PATTERN]      şemaları listele\n"
 
 #: help.c:251
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S] [PATTERN]     operatörleri listele\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [PATTERN]      operatörleri listele\n"
 
 #: help.c:252
 #, c-format
 msgid "  \\dO[S+] [PATTERN]      list collations\n"
-msgstr "  \\dO[S+]  [PATTERN]      collationları listele\n"
+msgstr "  \\dO[S+] [PATTERN]      collationları listele\n"
 
 #: help.c:253
 #, c-format
@@ -3027,22 +3027,22 @@ msgstr "  \\dy     [PATTERN]      olay tetikleyicilerini listele\n"
 #: help.c:265
 #, c-format
 msgid "  \\l[+]   [PATTERN]      list databases\n"
-msgstr "   \\l[+]   [PATTERN]      veritabanlarını listele\n"
+msgstr "  \\l[+]   [PATTERN]      veritabanlarını listele\n"
 
 #: help.c:266
 #, c-format
 msgid "  \\sf[+]  FUNCNAME       show a function's definition\n"
-msgstr " \\sf[+]  FUNCNAME       fonksiyonun tanımını göster\n"
+msgstr "  \\sf[+]  FUNCNAME       fonksiyonun tanımını göster\n"
 
 #: help.c:267
 #, c-format
 msgid "  \\sv[+]  VIEWNAME       show a view's definition\n"
-msgstr " \\sv[+]  VIEWNAME       görünümün (view) tanımını göster\n"
+msgstr "  \\sv[+]  VIEWNAME       görünümün (view) tanımını göster\n"
 
 #: help.c:268
 #, c-format
 msgid "  \\z      [PATTERN]      same as \\dp\n"
-msgstr "  \\z      [PATTERN]       \\dp ile aynı\n"
+msgstr "  \\z      [PATTERN]      \\dp ile aynı\n"
 
 #: help.c:271
 #, c-format
@@ -3052,17 +3052,17 @@ msgstr "Biçimlendirme:\n"
 #: help.c:272
 #, c-format
 msgid "  \\a                     toggle between unaligned and aligned output mode\n"
-msgstr "  \\a                    düzenli ve düzensiz çıktı modu arasında geçiş yap\n"
+msgstr "  \\a                     düzenli ve düzensiz çıktı modu arasında geçiş yap\n"
 
 #: help.c:273
 #, c-format
 msgid "  \\C [STRING]            set table title, or unset if none\n"
-msgstr "  \\C [DİZİ]            tablo başlığını ayarla, ya da boş bırakılırsa kaldır\n"
+msgstr "  \\C [DİZİ]              tablo başlığını ayarla, ya da boş bırakılırsa kaldır\n"
 
 #: help.c:274
 #, c-format
 msgid "  \\f [STRING]            show or set field separator for unaligned query output\n"
-msgstr "  \\f [DİZİ]            düzensiz sorgu çıktısı için alan ayracını göster ya da tanımla\n"
+msgstr "  \\f [DİZİ]              düzensiz sorgu çıktısı için alan ayracını göster ya da tanımla\n"
 
 #: help.c:275
 #, c-format
@@ -3097,12 +3097,12 @@ msgstr ""
 #: help.c:284
 #, c-format
 msgid "  \\t [on|off]            show only rows (currently %s)\n"
-msgstr "  \\t [on|off]             sadece satırları göster (şu an %s)\n"
+msgstr "  \\t [on|off]            sadece satırları göster (şu an %s)\n"
 
 #: help.c:286
 #, c-format
 msgid "  \\T [STRING]            set HTML <table> tag attributes, or unset if none\n"
-msgstr "  \\T [DİZGİ]            HTML <table>  parametrelerini tanımla, boş ise tüm parametrelerini kaldır\n"
+msgstr "  \\T [DİZGİ]             HTML <table>  parametrelerini tanımla, boş ise tüm parametrelerini kaldır\n"
 
 #: help.c:287
 #, c-format
@@ -3121,7 +3121,7 @@ msgid ""
 "                         connect to new database (currently \"%s\")\n"
 msgstr ""
 "  \\c[onnect] {[VTADI|- KULLANICIADI|- KARŞISUNUCU|- PORT|-] | conninfo}\n"
-"                        yeni veritabanına bağlan (geçerli veritabanı \"%s\")\n"
+"                         yeni veritabanına bağlan (geçerli veritabanı \"%s\")\n"
 
 #: help.c:297
 #, c-format
@@ -3170,7 +3170,7 @@ msgstr "  \\timing [on|off]       komutların çalışma zamanlamasının göste
 #: help.c:309
 #, c-format
 msgid "  \\! [COMMAND]           execute command in shell or start interactive shell\n"
-msgstr "  \\! [KOMUT]           komutu kabukta çalıştır ya da etkileşimli kabuğu başlat\n"
+msgstr "  \\! [KOMUT]             komutu kabukta çalıştır ya da etkileşimli kabuğu başlat\n"
 
 #: help.c:312
 #, c-format
@@ -3180,17 +3180,17 @@ msgstr "Değişkenler\n"
 #: help.c:313
 #, c-format
 msgid "  \\prompt [TEXT] NAME    prompt user to set internal variable\n"
-msgstr "  \\prompt [METİN] AD    kullanıcıdan dahili değişkeni değiştirmesini iste\n"
+msgstr "  \\prompt [METİN] AD     kullanıcıdan dahili değişkeni değiştirmesini iste\n"
 
 #: help.c:314
 #, c-format
 msgid "  \\set [NAME [VALUE]]    set internal variable, or list all if no parameters\n"
-msgstr "  \\set [AD [DEĞER]]    dahili değişkene değer ata, DEĞER boş ise tüm değişkenlerin listesini göster\n"
+msgstr "  \\set [AD [DEĞER]]      dahili değişkene değer ata, DEĞER boş ise tüm değişkenlerin listesini göster\n"
 
 #: help.c:315
 #, c-format
 msgid "  \\unset NAME            unset (delete) internal variable\n"
-msgstr "  \\unset AD            dahili değişkenleri sıfırla(sil)\n"
+msgstr "  \\unset AD              dahili değişkenleri sıfırla(sil)\n"
 
 #: help.c:318
 #, c-format
diff --git a/src/bin/psql/po/uk.po b/src/bin/psql/po/uk.po
index 5037f3a245..ea8ffe5607 100644
--- a/src/bin/psql/po/uk.po
+++ b/src/bin/psql/po/uk.po
@@ -2648,7 +2648,7 @@ msgstr "  \\gexec                 виконати запит, потім вик
 #: help.c:182
 #, c-format
 msgid "  \\gset [PREFIX]         execute query and store results in psql variables\n"
-msgstr "  \\gset [PREFIX]        виконати запит та зберегти результати в змінних psql \n"
+msgstr "  \\gset [PREFIX]         виконати запит та зберегти результати в змінних psql \n"
 
 #: help.c:183
 #, c-format
@@ -2698,12 +2698,12 @@ msgstr "Буфер запитів\n"
 #: help.c:197
 #, c-format
 msgid "  \\e [FILE] [LINE]       edit the query buffer (or file) with external editor\n"
-msgstr "  \\e [FILE] [LINE]        редагувати буфер запитів (або файл) зовнішнім редактором\n"
+msgstr "  \\e [FILE] [LINE]       редагувати буфер запитів (або файл) зовнішнім редактором\n"
 
 #: help.c:198
 #, c-format
 msgid "  \\ef [FUNCNAME [LINE]]  edit function definition with external editor\n"
-msgstr "  \\ef [FUNCNAME [LINE]]   редагувати визначення функції  зовнішнім редактором\n"
+msgstr "  \\ef [FUNCNAME [LINE]]  редагувати визначення функції  зовнішнім редактором\n"
 
 #: help.c:199
 #, c-format
@@ -2718,7 +2718,7 @@ msgstr "  \\p                     показати вміст буфера за
 #: help.c:201
 #, c-format
 msgid "  \\r                     reset (clear) the query buffer\n"
-msgstr "  \\r                    скинути (очистити) буфер запитів\n"
+msgstr "  \\r                     скинути (очистити) буфер запитів\n"
 
 #: help.c:203
 #, c-format
@@ -2748,17 +2748,17 @@ msgstr "  \\echo [-n] [STRING]    записати рядок до станда
 #: help.c:211
 #, c-format
 msgid "  \\i FILE                execute commands from file\n"
-msgstr "  \\i FILE              виконати команди з файлу\n"
+msgstr "  \\i FILE                виконати команди з файлу\n"
 
 #: help.c:212
 #, c-format
 msgid "  \\ir FILE               as \\i, but relative to location of current script\n"
-msgstr "  \\ir ФАЙЛ              те саме, що \\i, але відносно розташування поточного сценарію\n"
+msgstr "  \\ir ФАЙЛ               те саме, що \\i, але відносно розташування поточного сценарію\n"
 
 #: help.c:213
 #, c-format
 msgid "  \\o [FILE]              send all query results to file or |pipe\n"
-msgstr "  \\o [FILE]            надсилати всі результати запитів до файлу або до каналу |\n"
+msgstr "  \\o [FILE]              надсилати всі результати запитів до файлу або до каналу |\n"
 
 #: help.c:214
 #, c-format
@@ -2778,12 +2778,12 @@ msgstr "Умовний\n"
 #: help.c:219
 #, c-format
 msgid "  \\if EXPR               begin conditional block\n"
-msgstr "  \\if EXPR              початок умовного блоку\n"
+msgstr "  \\if EXPR               початок умовного блоку\n"
 
 #: help.c:220
 #, c-format
 msgid "  \\elif EXPR             alternative within current conditional block\n"
-msgstr "  \\elif EXPR            альтернатива в рамках поточного блоку\n"
+msgstr "  \\elif EXPR             альтернатива в рамках поточного блоку\n"
 
 #: help.c:221
 #, c-format
@@ -2793,7 +2793,7 @@ msgstr "  \\else                  остаточна альтернатива в
 #: help.c:222
 #, c-format
 msgid "  \\endif                 end conditional block\n"
-msgstr "  \\endif                  кінець умовного блоку\n"
+msgstr "  \\endif                 кінець умовного блоку\n"
 
 #: help.c:225
 #, c-format
@@ -2842,8 +2842,8 @@ msgstr "  \\dAo[+] [AMPTRN [OPFPTRN]]   список операторів сім
 
 #: help.c:234
 #, c-format
-msgid "  \\dAp    [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
-msgstr "  \\dAp    [AMPTRN [OPFPTRN]]   список функцій підтримки сімейств операторів\n"
+msgid "  \\dAp[+] [AMPTRN [OPFPTRN]]   list support functions of operator families\n"
+msgstr "  \\dAp[+] [AMPTRN [OPFPTRN]]   список функцій підтримки сімейств операторів\n"
 
 #: help.c:235
 #, c-format
@@ -2957,8 +2957,8 @@ msgstr "  \\dn[S+] [PATTERN]      вивести схеми\n"
 
 #: help.c:257
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [PATTERN]      вивести оператори\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [PATTERN]      вивести оператори\n"
 
 #: help.c:258
 #, c-format
@@ -3058,7 +3058,7 @@ msgstr "  \\a                     перемикання між режимами
 #: help.c:279
 #, c-format
 msgid "  \\C [STRING]            set table title, or unset if none\n"
-msgstr "  \\C [STRING]           встановити заголовок таблиці або прибрати, якщо не задано\n"
+msgstr "  \\C [STRING]            встановити заголовок таблиці або прибрати, якщо не задано\n"
 
 #: help.c:280
 #, c-format
@@ -3090,7 +3090,7 @@ msgstr "  \\pset [NAME [VALUE]]   встановити параметр виво
 #: help.c:290
 #, c-format
 msgid "  \\t [on|off]            show only rows (currently %s)\n"
-msgstr "  \\t [on|off]          показувати лише рядки (поточно %s)\n"
+msgstr "  \\t [on|off]            показувати лише рядки (поточно %s)\n"
 
 #: help.c:292
 #, c-format
@@ -3111,18 +3111,20 @@ msgstr "Підключення\n"
 #, c-format
 msgid "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}\n"
 "                         connect to new database (currently \"%s\")\n"
-msgstr "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}                          під'єднатися до нової бази даних (поточно \"%s\")\n"
+msgstr "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}\n"
+"                         під'єднатися до нової бази даних (поточно \"%s\")\n"
 
 #: help.c:303
 #, c-format
 msgid "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}\n"
 "                         connect to new database (currently no connection)\n"
-msgstr "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}                          під'єднатися до нової бази даних (зараз з'єднання відсутнє)\n"
+msgstr "  \\c[onnect] {[DBNAME|- USER|- HOST|- PORT|-] | conninfo}\n"
+"                         під'єднатися до нової бази даних (зараз з'єднання відсутнє)\n"
 
 #: help.c:305
 #, c-format
 msgid "  \\conninfo              display information about current connection\n"
-msgstr "  \\conninfo             показати інформацію про поточне з'єднання\n"
+msgstr "  \\conninfo              показати інформацію про поточне з'єднання\n"
 
 #: help.c:306
 #, c-format
@@ -3132,7 +3134,7 @@ msgstr "  \\encoding [ENCODING]   показати або встановити 
 #: help.c:307
 #, c-format
 msgid "  \\password [USERNAME]   securely change the password for a user\n"
-msgstr "  \\password [USERNAME]  безпечно змінити пароль користувача \n"
+msgstr "  \\password [USERNAME]   безпечно змінити пароль користувача \n"
 
 #: help.c:310
 #, c-format
@@ -3142,7 +3144,7 @@ msgstr "Операційна система\n"
 #: help.c:311
 #, c-format
 msgid "  \\cd [DIR]              change the current working directory\n"
-msgstr "  \\cd [DIR]             змінити поточний робочий каталог\n"
+msgstr "  \\cd [DIR]              змінити поточний робочий каталог\n"
 
 #: help.c:312
 #, c-format
diff --git a/src/bin/psql/po/zh_CN.po b/src/bin/psql/po/zh_CN.po
index 79c4ddaaf0..8ceb8fcc0e 100644
--- a/src/bin/psql/po/zh_CN.po
+++ b/src/bin/psql/po/zh_CN.po
@@ -2826,8 +2826,8 @@ msgstr "  \\dn[S+] [模式]         列出所有模式\n"
 
 #: help.c:251
 #, c-format
-msgid "  \\do[S]  [PATTERN]      list operators\n"
-msgstr "  \\do[S]  [模式]         列出运算符\n"
+msgid "  \\do[S+] [PATTERN]      list operators\n"
+msgstr "  \\do[S+] [模式]         列出运算符\n"
 
 #: help.c:252
 #, c-format
@@ -2891,8 +2891,8 @@ msgstr "  \\dx[+]  [模式]         列出扩展\n"
 
 #: help.c:264
 #, c-format
-msgid "  \\dy     [PATTERN]      list event triggers\n"
-msgstr "  \\dy     [模式]         列出所有事件触发器\n"
+msgid "  \\dy[+]  [PATTERN]      list event triggers\n"
+msgstr "  \\dy[+]  [模式]         列出所有事件触发器\n"
 
 #: help.c:265
 #, c-format
-- 
2.30.2

